import { ConfigurableSerdeContext, SerdeFunctions } from "@smithy/types";
export declare class SerdeContextConfig implements ConfigurableSerdeContext {
  protected serdeContext?: SerdeFunctions;
  setSerdeContext(serdeContext: SerdeFunctions): void;
}
