import { CodecSettings } from "@smithy/types";
export type QuerySerializerSettings = CodecSettings & {
  capitalizeKeys?: boolean;
  flattenLists?: boolean;
  serializeEmptyLists?: boolean;
  ec2?: boolean;
};
