import type { ConfigurableSerdeContext, SerdeFunctions } from "@smithy/types";
/**
 * @internal
 */
export declare class SerdeContextConfig implements ConfigurableSerdeContext {
    protected serdeContext?: SerdeFunctions;
    setSerdeContext(serdeContext: SerdeFunctions): void;
}
