import { AwsQueryProtocol } from "./AwsQueryProtocol";
export declare class AwsEc2QueryProtocol extends AwsQueryProtocol {
  options: {
    defaultNamespace: string;
    xmlNamespace: string;
    version: string;
  };
  constructor(options: {
    defaultNamespace: string;
    xmlNamespace: string;
    version: string;
  });
  protected useNestedResult(): boolean;
}
