import { HttpResponse, SerdeFunctions } from "@smithy/types";
export declare const parseJsonBody: (
  streamBody: any,
  context: SerdeFunctions
) => any;
export declare const parseJsonErrorBody: (
  errorBody: any,
  context: SerdeFunctions
) => Promise<any>;
export declare const loadRestJsonErrorCode: (
  output: HttpResponse,
  data: any
) => string | undefined;
